@@ -1,30 +1,26 @@
 /*
- *  Copyright 2008 Friedrich W. H. Kossebau  <kossebau@kde.org>
- *  Copyright 2017 Harald Sitter <sitter@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation;
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2017 Harald Sitter <sitter@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 // test object
 #include <kaboutdata.h>
 // Qt
-#include <QObject>
 #include <QFile>
-#include <QTextStream>
-#include <QTest>
 #include <QLatin1String>
+#include <QObject>
+#include <QTest>
+#include <QTextStream>
+#ifndef Q_OS_WIN
+void initLocale()
+{
+    qputenv("LC_ALL", "en_US.utf-8");
+}
+
+Q_CONSTRUCTOR_FUNCTION(initLocale)
+#endif
 
 class KAboutDataTest : public QObject
 {
@@ -35,7 +31,6 @@ private Q_SLOTS:
     void testLongFormConstructor();
     void testShortFormConstructor();
     void testSetAddLicense();
-    void testSetProgramIconName();
     void testSetDesktopFileName();
     void testCopying();
 
@@ -43,32 +38,35 @@ private Q_SLOTS:
 
     void testLicenseSPDXID();
     void testLicenseOrLater();
+
+    void testProductName();
 };
 
-static const char AppName[] =            "app";
-static const char ProgramName[] =        "ProgramName";
-static const char ProgramIconName[] =    "program-icon";
-static const char Version[] =            "Version";
-static const char ShortDescription[] =   "ShortDescription";
+static const char AppName[] = "app";
+static const char ProgramName[] = "ProgramName";
+static const char Version[] = "Version";
+static const char ShortDescription[] = "ShortDescription";
 static const char CopyrightStatement[] = "CopyrightStatement";
-static const char Text[] =               "Text";
-static const char HomePageAddress[] =    "http://test.no.where/";
-static const char HomePageSecure[] =     "https://test.no.where/";
+static const char Text[] = "Text";
+static const char HomePageAddress[] = "http://test.no.where/";
+static const char HomePageSecure[] = "https://test.no.where/";
 static const char OrganizationDomain[] = "no.where";
-static const char BugsEmailAddress[] =   "bugs@no.else";
-static const char LicenseText[] =        "free to write, reading forbidden";
-static const char LicenseFileName[] =    "testlicensefile";
-static const char LicenseFileText[] =    "free to write, reading forbidden, in the file";
+static const char BugsEmailAddress[] = "bugs@no.else";
+static const char LicenseText[] = "free to write, reading forbidden";
+static const char LicenseFileName[] = "testlicensefile";
+static const char LicenseFileText[] = "free to write, reading forbidden, in the file";
 
 void KAboutDataTest::testLongFormConstructorWithDefaults()
 {
-    KAboutData aboutData(QString::fromLatin1(AppName), QLatin1String(ProgramName), QString::fromLatin1(Version),
-                         QLatin1String(ShortDescription), KAboutLicense::Unknown);
+    KAboutData aboutData(QString::fromLatin1(AppName),
+                         QLatin1String(ProgramName),
+                         QString::fromLatin1(Version),
+                         QLatin1String(ShortDescription),
+                         KAboutLicense::Unknown);
 
     QCOMPARE(aboutData.componentName(), QString::fromLatin1(AppName));
     QCOMPARE(aboutData.productName(), QString::fromLatin1(AppName));
     QCOMPARE(aboutData.displayName(), QLatin1String(ProgramName));
-    QCOMPARE(aboutData.programIconName(), QString::fromLatin1(AppName));
     QCOMPARE(aboutData.programLogo(), QVariant());
     QCOMPARE(aboutData.organizationDomain(), QString::fromLatin1("kde.org"));
     QCOMPARE(aboutData.version(), QString::fromLatin1(Version));
@@ -92,20 +90,28 @@ void KAboutDataTest::testLongFormConstructorWithDefaults()
     QCOMPARE(aboutData.customAuthorRichText(), QString());
     QVERIFY(!aboutData.customAuthorTextEnabled());
     QCOMPARE(aboutData.desktopFileName(), QStringLiteral("org.kde.app"));
-    //TODO: test internalVersion, internalProgramName, internalBugAddress
+
+    QCOMPARE(aboutData.internalVersion(), Version);
+    QCOMPARE(aboutData.internalProgramName(), ProgramName);
+    QCOMPARE(aboutData.internalBugAddress(), "submit@bugs.kde.org");
+    QCOMPARE(aboutData.internalProductName(), nullptr);
 }
 
 void KAboutDataTest::testLongFormConstructor()
 {
-    KAboutData aboutData(QString::fromLatin1(AppName), QLatin1String(ProgramName), QString::fromLatin1(Version),
-                         QLatin1String(ShortDescription), KAboutLicense::Unknown,
-                         QLatin1String(CopyrightStatement), QLatin1String(Text),
-                         QString::fromLatin1(HomePageAddress), QString::fromLatin1(BugsEmailAddress));
+    KAboutData aboutData(QString::fromLatin1(AppName),
+                         QLatin1String(ProgramName),
+                         QString::fromLatin1(Version),
+                         QLatin1String(ShortDescription),
+                         KAboutLicense::Unknown,
+                         QLatin1String(CopyrightStatement),
+                         QLatin1String(Text),
+                         QString::fromLatin1(HomePageAddress),
+                         QString::fromLatin1(BugsEmailAddress));
 
     QCOMPARE(aboutData.componentName(), QLatin1String(AppName));
     QCOMPARE(aboutData.productName(), QLatin1String(AppName));
     QCOMPARE(aboutData.displayName(), QLatin1String(ProgramName));
-    QCOMPARE(aboutData.programIconName(), QLatin1String(AppName));
     QCOMPARE(aboutData.programLogo(), QVariant());
     QCOMPARE(aboutData.organizationDomain(), QString::fromLatin1(OrganizationDomain));
     QCOMPARE(aboutData.version(), QString::fromLatin1(Version));
@@ -129,14 +135,32 @@ void KAboutDataTest::testLongFormConstructor()
     QCOMPARE(aboutData.customAuthorRichText(), QString());
     QVERIFY(!aboutData.customAuthorTextEnabled());
     QCOMPARE(aboutData.desktopFileName(), QStringLiteral("where.no.app"));
-    //TODO: test internalVersion, internalProgramName, internalBugAddress
+
+    QCOMPARE(aboutData.internalVersion(), Version);
+    QCOMPARE(aboutData.internalProgramName(), ProgramName);
+    QCOMPARE(aboutData.internalBugAddress(), BugsEmailAddress);
+    QCOMPARE(aboutData.internalProductName(), nullptr);
+
+    aboutData.addAuthor(QStringLiteral("John"),
+                        QStringLiteral("Stuff"),
+                        QStringLiteral("john@john.com"),
+                        QStringLiteral("john.com"),
+                        QStringLiteral("ocsjohn"));
+    QCOMPARE(aboutData.authors().length(), 1);
+    QCOMPARE(aboutData.credits().length(), 0);
+    QCOMPARE(aboutData.authors().at(0).avatarUrl(), QUrl(QStringLiteral("https://store.kde.org/avatar/ocsjohn")));
 
     // We support http and https protocols on the homepage address, ensure they
     // give the same org. domain and desktop file name.
-    KAboutData aboutDataSecure(QString::fromLatin1(AppName), QLatin1String(ProgramName), QString::fromLatin1(Version),
-                               QLatin1String(ShortDescription), KAboutLicense::Unknown,
-                               QLatin1String(CopyrightStatement), QLatin1String(Text),
-                               QString::fromLatin1(HomePageSecure), QString::fromLatin1(BugsEmailAddress));
+    KAboutData aboutDataSecure(QString::fromLatin1(AppName),
+                               QLatin1String(ProgramName),
+                               QString::fromLatin1(Version),
+                               QLatin1String(ShortDescription),
+                               KAboutLicense::Unknown,
+                               QLatin1String(CopyrightStatement),
+                               QLatin1String(Text),
+                               QString::fromLatin1(HomePageSecure),
+                               QString::fromLatin1(BugsEmailAddress));
     QCOMPARE(aboutDataSecure.componentName(), QLatin1String(AppName));
     QCOMPARE(aboutDataSecure.productName(), QLatin1String(AppName));
     QCOMPARE(aboutDataSecure.organizationDomain(), QString::fromLatin1(OrganizationDomain));
@@ -150,7 +174,6 @@ void KAboutDataTest::testShortFormConstructor()
     QCOMPARE(aboutData.componentName(), QString::fromLatin1(AppName));
     QCOMPARE(aboutData.productName(), QString::fromLatin1(AppName));
     QCOMPARE(aboutData.displayName(), QLatin1String(ProgramName));
-    QCOMPARE(aboutData.programIconName(), QString::fromLatin1(AppName));
     QCOMPARE(aboutData.programLogo(), QVariant());
     QCOMPARE(aboutData.organizationDomain(), QString::fromLatin1("kde.org"));
     QCOMPARE(aboutData.version(), QString::fromLatin1(Version));
@@ -174,21 +197,33 @@ void KAboutDataTest::testShortFormConstructor()
     QCOMPARE(aboutData.customAuthorRichText(), QString());
     QVERIFY(!aboutData.customAuthorTextEnabled());
     QCOMPARE(aboutData.desktopFileName(), QStringLiteral("org.kde.app"));
-    //TODO: test internalVersion, internalProgramName, internalBugAddress
+
+    QCOMPARE(aboutData.internalVersion(), Version);
+    QCOMPARE(aboutData.internalProgramName(), ProgramName);
+    QCOMPARE(aboutData.internalBugAddress(), "submit@bugs.kde.org");
+    QCOMPARE(aboutData.internalProductName(), nullptr);
 }
 
 void KAboutDataTest::testKAboutDataOrganizationDomain()
 {
-    KAboutData data(QString::fromLatin1("app"), QLatin1String("program"), QString::fromLatin1("version"),
-                    QLatin1String("description"), KAboutLicense::LGPL,
-                    QLatin1String("copyright"), QLatin1String("hello world"),
+    KAboutData data(QString::fromLatin1("app"),
+                    QLatin1String("program"),
+                    QString::fromLatin1("version"),
+                    QLatin1String("description"),
+                    KAboutLicense::LGPL,
+                    QLatin1String("copyright"),
+                    QLatin1String("hello world"),
                     QStringLiteral("http://www.koffice.org"));
     QCOMPARE(data.organizationDomain(), QString::fromLatin1("koffice.org"));
     QCOMPARE(data.desktopFileName(), QStringLiteral("org.koffice.app"));
 
-    KAboutData data2(QString::fromLatin1("app"), QLatin1String("program"), QString::fromLatin1("version"),
-                     QLatin1String("description"), KAboutLicense::LGPL,
-                     QString::fromLatin1("copyright"), QLatin1String("hello world"),
+    KAboutData data2(QString::fromLatin1("app"),
+                     QLatin1String("program"),
+                     QString::fromLatin1("version"),
+                     QLatin1String("description"),
+                     KAboutLicense::LGPL,
+                     QString::fromLatin1("copyright"),
+                     QLatin1String("hello world"),
                      QStringLiteral("app"));
     QCOMPARE(data2.organizationDomain(), QString::fromLatin1("kde.org"));
     QCOMPARE(data2.desktopFileName(), QStringLiteral("org.kde.app"));
@@ -206,10 +241,15 @@ void KAboutDataTest::testSetAddLicense()
     const QString copyrightStatement = QLatin1String(CopyrightStatement);
     const QString lineFeed = QString::fromLatin1("\n\n");
 
-    KAboutData aboutData(QString::fromLatin1(AppName), QLatin1String(ProgramName), QString::fromLatin1(Version),
-                         QLatin1String(ShortDescription), KAboutLicense::Unknown,
-                         QLatin1String(CopyrightStatement), QLatin1String(Text),
-                         QString::fromLatin1(HomePageAddress), QString::fromLatin1(BugsEmailAddress));
+    KAboutData aboutData(QString::fromLatin1(AppName),
+                         QLatin1String(ProgramName),
+                         QString::fromLatin1(Version),
+                         QLatin1String(ShortDescription),
+                         KAboutLicense::Unknown,
+                         QLatin1String(CopyrightStatement),
+                         QLatin1String(Text),
+                         QString::fromLatin1(HomePageAddress),
+                         QString::fromLatin1(BugsEmailAddress));
 
     // set to GPL2
     aboutData.setLicense(KAboutLicense::GPL_V2);
@@ -260,36 +300,23 @@ void KAboutDataTest::testSetAddLicense()
     QCOMPARE(aboutData.licenses().at(2).text(), QLatin1String(LicenseText));
     QCOMPARE(aboutData.licenses().at(3).name(KAboutLicense::ShortName), QString::fromLatin1("Custom"));
     QCOMPARE(aboutData.licenses().at(3).name(KAboutLicense::FullName), QString::fromLatin1("Custom"));
-    QCOMPARE(aboutData.licenses().at(3).text(), QString(copyrightStatement + lineFeed +
-                                                        QLatin1String(LicenseFileText)));
-}
-
-void KAboutDataTest::testSetProgramIconName()
-{
-    const QString programIconName(QString::fromLatin1(ProgramIconName));
-
-    KAboutData aboutData(QString::fromLatin1(AppName), QLatin1String(ProgramName), QString::fromLatin1(Version),
-                         QLatin1String(ShortDescription), KAboutLicense::Unknown,
-                         QLatin1String(CopyrightStatement), QLatin1String(Text),
-                         QString::fromLatin1(HomePageAddress), QString::fromLatin1(BugsEmailAddress));
-
-    // Deprecated, still want to test this though. Silence GCC warnings.
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-    // set different iconname
-    aboutData.setProgramIconName(programIconName);
-#pragma GCC diagnostic pop
-    QCOMPARE(aboutData.programIconName(), programIconName);
+    QCOMPARE(aboutData.licenses().at(3).text(), QString(copyrightStatement + lineFeed + QLatin1String(LicenseFileText)));
 }
 
 void KAboutDataTest::testCopying()
 {
-    KAboutData aboutData(QString::fromLatin1(AppName), QLatin1String(ProgramName), QString::fromLatin1(Version),
-                         QLatin1String(ShortDescription), KAboutLicense::GPL_V2);
+    KAboutData aboutData(QString::fromLatin1(AppName),
+                         QLatin1String(ProgramName),
+                         QString::fromLatin1(Version),
+                         QLatin1String(ShortDescription),
+                         KAboutLicense::GPL_V2);
 
     {
-        KAboutData aboutData2(QString::fromLatin1(AppName), QLatin1String(ProgramName), QString::fromLatin1(Version),
-                              QLatin1String(ShortDescription), KAboutLicense::GPL_V3);
+        KAboutData aboutData2(QString::fromLatin1(AppName),
+                              QLatin1String(ProgramName),
+                              QString::fromLatin1(Version),
+                              QLatin1String(ShortDescription),
+                              KAboutLicense::GPL_V3);
         aboutData2.addLicense(KAboutLicense::GPL_V2, KAboutLicense::OrLaterVersions);
         aboutData = aboutData2;
     }
@@ -307,8 +334,11 @@ void KAboutDataTest::testCopying()
 
 void KAboutDataTest::testSetDesktopFileName()
 {
-    KAboutData aboutData(QString::fromLatin1(AppName), QLatin1String(ProgramName), QString::fromLatin1(Version),
-                         QLatin1String(ShortDescription), KAboutLicense::Unknown);
+    KAboutData aboutData(QString::fromLatin1(AppName),
+                         QLatin1String(ProgramName),
+                         QString::fromLatin1(Version),
+                         QLatin1String(ShortDescription),
+                         KAboutLicense::Unknown);
     QCOMPARE(aboutData.desktopFileName(), QStringLiteral("org.kde.app"));
 
     // set different desktopFileName
@@ -325,14 +355,17 @@ void KAboutDataTest::testLicenseSPDXID()
     license = KAboutLicense::byKeyword(QStringLiteral("GPLv2"));
     QCOMPARE(license.spdx(), QStringLiteral("GPL-2.0"));
 
-    //we should be able to match by spdx too
-    //create a KAboutLicense from enum, then make sure going to spdx and back gives the same enum
-    for(int i = 1; i <= KAboutLicense::LGPL_V2_1 ; ++i) { /*current highest enum value*/
-        KAboutData aboutData(QString::fromLatin1(AppName), QLatin1String(ProgramName), QString::fromLatin1(Version),
-                                    QLatin1String(ShortDescription), KAboutLicense::GPL_V2);
+    // we should be able to match by spdx too
+    // create a KAboutLicense from enum, then make sure going to spdx and back gives the same enum
+    for (int i = 1; i <= KAboutLicense::LGPL_V2_1; ++i) { /*current highest enum value*/
+        KAboutData aboutData(QString::fromLatin1(AppName),
+                             QLatin1String(ProgramName),
+                             QString::fromLatin1(Version),
+                             QLatin1String(ShortDescription),
+                             KAboutLicense::GPL_V2);
         aboutData.setLicense(KAboutLicense::LicenseKey(i));
         QVERIFY(aboutData.licenses().count() == 1);
-        auto license = aboutData.licenses()[0];
+        const auto license = aboutData.licenses().constFirst();
         auto licenseFromKeyword = KAboutLicense::byKeyword(license.spdx());
 
         QCOMPARE(license.key(), licenseFromKeyword.key());
@@ -342,14 +375,18 @@ void KAboutDataTest::testLicenseSPDXID()
 void KAboutDataTest::testLicenseOrLater()
 {
     // For kaboutdata we can replace the license with an orLater version. Or add a second one.
-    KAboutData aboutData(QString::fromLatin1(AppName), QLatin1String(ProgramName), QString::fromLatin1(Version),
-                         QLatin1String(ShortDescription), KAboutLicense::GPL_V2);
+    KAboutData aboutData(QString::fromLatin1(AppName),
+                         QLatin1String(ProgramName),
+                         QString::fromLatin1(Version),
+                         QLatin1String(ShortDescription),
+                         KAboutLicense::GPL_V2);
     QCOMPARE(aboutData.licenses().at(0).spdx(), QStringLiteral("GPL-2.0"));
     aboutData.setLicense(KAboutLicense::GPL_V2, KAboutLicense::OrLaterVersions);
     QCOMPARE(aboutData.licenses().at(0).spdx(), QStringLiteral("GPL-2.0+"));
     aboutData.addLicense(KAboutLicense::LGPL_V3, KAboutLicense::OrLaterVersions);
     bool foundLGPL = false;
-    for (auto license : aboutData.licenses()) {
+    const QList<KAboutLicense> licenses = aboutData.licenses();
+    for (const auto &license : licenses) {
         if (license.key() == KAboutLicense::LGPL_V3) {
             QCOMPARE(license.spdx(), QStringLiteral("LGPL-3.0+"));
             foundLGPL = true;
@@ -359,6 +396,16 @@ void KAboutDataTest::testLicenseOrLater()
     QCOMPARE(foundLGPL, true);
 }
 
+void KAboutDataTest::testProductName()
+{
+    KAboutData aboutData(QString::fromLatin1(AppName), QString::fromLatin1(ProgramName));
+    QCOMPARE(aboutData.productName(), QString::fromLatin1(AppName));
+    QCOMPARE(aboutData.internalProductName(), nullptr);
+    aboutData.setProductName("frameworks-kcoreaddons/aboutdata");
+    QCOMPARE(aboutData.productName(), QString::fromLatin1("frameworks-kcoreaddons/aboutdata"));
+    QCOMPARE(aboutData.internalProductName(), "frameworks-kcoreaddons/aboutdata");
+}
+
 QTEST_MAIN(KAboutDataTest)
 
 #include "kaboutdatatest.moc"
