@@ -214,7 +214,7 @@ static std::optional<QStringList> fuseRedirect(QList<QUrl> urls, bool onlyLocalF
         int urlIndex;
         QString basename;
     };
-    QVector<MountRequest> requests;
+    QList<MountRequest> requests;
     requests.reserve(urls.count());
     for (int i = 0; i < urls.count(); ++i) {
         QUrl url = urls.at(i);
