@@ -13,7 +13,6 @@
 
 #include "kaboutdata.h"
 #include "kjsonutils.h"
-#include "kpluginmetadata.h"
 
 #include <QCommandLineOption>
 #include <QCommandLineParser>
@@ -41,17 +40,17 @@ public:
     QString _task;
     QString _emailAddress;
     QString _webAddress;
-    QString _ocsUsername;
+    QUrl _avatarUrl;
 };
 
-KAboutPerson::KAboutPerson(const QString &_name, const QString &_task, const QString &_emailAddress, const QString &_webAddress, const QString &_ocsUsername)
+KAboutPerson::KAboutPerson(const QString &_name, const QString &_task, const QString &_emailAddress, const QString &_webAddress, const QUrl &avatarUrl)
     : d(new KAboutPersonPrivate)
 {
     d->_name = _name;
     d->_task = _task;
     d->_emailAddress = _emailAddress;
     d->_webAddress = _webAddress;
-    d->_ocsUsername = _ocsUsername;
+    d->_avatarUrl = avatarUrl;
 }
 
 KAboutPerson::KAboutPerson(const QString &_name, const QString &_email, bool)
@@ -85,9 +84,9 @@ QString KAboutPerson::webAddress() const
     return d->_webAddress;
 }
 
-QString KAboutPerson::ocsUsername() const
+QUrl KAboutPerson::avatarUrl() const
 {
-    return d->_ocsUsername;
+    return d->_avatarUrl;
 }
 
 KAboutPerson &KAboutPerson::operator=(const KAboutPerson &other) = default;
@@ -96,10 +95,10 @@ KAboutPerson KAboutPerson::fromJSON(const QJsonObject &obj)
 {
     const QString name = KJsonUtils::readTranslatedString(obj, QStringLiteral("Name"));
     const QString task = KJsonUtils::readTranslatedString(obj, QStringLiteral("Task"));
-    const QString email = obj[QStringLiteral("Email")].toString();
-    const QString website = obj[QStringLiteral("Website")].toString();
-    const QString userName = obj[QStringLiteral("UserName")].toString();
-    return KAboutPerson(name, task, email, website, userName);
+    const QString email = obj.value(QLatin1String("Email")).toString();
+    const QString website = obj.value(QLatin1String("Website")).toString();
+    const QUrl avatarUrl = obj.value(QLatin1String("AvatarUrl")).toVariant().toUrl();
+    return KAboutPerson(name, task, email, website, avatarUrl);
 }
 
 class KAboutLicensePrivate : public QSharedData
@@ -149,14 +148,14 @@ QString KAboutLicensePrivate::spdxID() const
         return QStringLiteral("BSD-2-Clause");
     case KAboutLicense::Artistic:
         return QStringLiteral("Artistic-1.0");
-    case KAboutLicense::QPL_V1_0:
-        return QStringLiteral("QPL-1.0");
     case KAboutLicense::GPL_V3:
         return QStringLiteral("GPL-3.0");
     case KAboutLicense::LGPL_V3:
         return QStringLiteral("LGPL-3.0");
     case KAboutLicense::LGPL_V2_1:
         return QStringLiteral("LGPL-2.1");
+    case KAboutLicense::MIT:
+        return QStringLiteral("MIT");
     case KAboutLicense::Custom:
     case KAboutLicense::File:
     case KAboutLicense::Unknown:
@@ -238,10 +237,6 @@ QString KAboutLicense::text() const
         knownLicense = true;
         pathToFile = QStringLiteral("ARTISTIC");
         break;
-    case KAboutLicense::QPL_V1_0:
-        knownLicense = true;
-        pathToFile = QStringLiteral("QPL_V1.0");
-        break;
     case KAboutLicense::GPL_V3:
         knownLicense = true;
         pathToFile = QStringLiteral("GPL_V3");
@@ -254,6 +249,10 @@ QString KAboutLicense::text() const
         knownLicense = true;
         pathToFile = QStringLiteral("LGPL_V21");
         break;
+    case KAboutLicense::MIT:
+        knownLicense = true;
+        pathToFile = QStringLiteral("MIT");
+        break;
     case KAboutLicense::Custom:
         if (!d->_licenseText.isEmpty()) {
             result = d->_licenseText;
@@ -269,7 +268,7 @@ QString KAboutLicense::text() const
     }
 
     if (knownLicense) {
-        pathToFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf" QT_STRINGIFY(QT_VERSION_MAJOR) "/licenses/") + pathToFile);
+        pathToFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf6/licenses/") + pathToFile);
         result += QCoreApplication::translate("KAboutLicense", "This program is distributed under the terms of the %1.").arg(name(KAboutLicense::ShortName));
         if (!pathToFile.isEmpty()) {
             result += lineFeed;
@@ -329,10 +328,6 @@ QString KAboutLicense::name(KAboutLicense::NameFormat formatName) const
         licenseShort = QCoreApplication::translate("KAboutLicense", "Artistic License", "@item license (short name)");
         licenseFull = QCoreApplication::translate("KAboutLicense", "Artistic License", "@item license");
         break;
-    case KAboutLicense::QPL_V1_0:
-        licenseShort = QCoreApplication::translate("KAboutLicense", "QPL v1.0", "@item license (short name)");
-        licenseFull = QCoreApplication::translate("KAboutLicense", "Q Public License", "@item license");
-        break;
     case KAboutLicense::GPL_V3:
         licenseShort = QCoreApplication::translate("KAboutLicense", "GPL v3", "@item license (short name)");
         licenseFull = QCoreApplication::translate("KAboutLicense", "GNU General Public License Version 3", "@item license");
@@ -345,6 +340,10 @@ QString KAboutLicense::name(KAboutLicense::NameFormat formatName) const
         licenseShort = QCoreApplication::translate("KAboutLicense", "LGPL v2.1", "@item license (short name)");
         licenseFull = QCoreApplication::translate("KAboutLicense", "GNU Lesser General Public License Version 2.1", "@item license");
         break;
+    case KAboutLicense::MIT:
+        licenseShort = QCoreApplication::translate("KAboutLicense", "MIT License", "@item license (short name)");
+        licenseFull = QCoreApplication::translate("KAboutLicense", "MIT License", "@item license");
+        break;
     case KAboutLicense::Custom:
     case KAboutLicense::File:
         licenseShort = licenseFull = QCoreApplication::translate("KAboutLicense", "Custom", "@item license");
@@ -381,14 +380,13 @@ KAboutLicense KAboutLicense::byKeyword(const QString &rawKeyword)
         {"lgpl20", KAboutLicense::LGPL_V2},    {"lgpl20+", KAboutLicense::LGPL_V2},
         {"bsd", KAboutLicense::BSDL},          {"bsd2clause", KAboutLicense::BSDL},
         {"artistic", KAboutLicense::Artistic}, {"artistic10", KAboutLicense::Artistic},
-        {"qpl", KAboutLicense::QPL},           {"qplv1", KAboutLicense::QPL_V1_0},
-        {"qplv10", KAboutLicense::QPL_V1_0},   {"qpl10", KAboutLicense::QPL_V1_0},
         {"gplv3", KAboutLicense::GPL_V3},      {"gplv3+", KAboutLicense::GPL_V3},
         {"gpl30", KAboutLicense::GPL_V3},      {"gpl30+", KAboutLicense::GPL_V3},
         {"lgplv3", KAboutLicense::LGPL_V3},    {"lgplv3+", KAboutLicense::LGPL_V3},
         {"lgpl30", KAboutLicense::LGPL_V3},    {"lgpl30+", KAboutLicense::LGPL_V3},
         {"lgplv21", KAboutLicense::LGPL_V2_1}, {"lgplv21+", KAboutLicense::LGPL_V2_1},
         {"lgpl21", KAboutLicense::LGPL_V2_1},  {"lgpl21+", KAboutLicense::LGPL_V2_1},
+        {"mit", KAboutLicense::MIT},
     };
 
     // Normalize keyword.
@@ -491,15 +489,11 @@ public:
     QList<KAboutPerson> _translatorList;
     QList<KAboutComponent> _componentList;
     QList<KAboutLicense> _licenseList;
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 2)
-    QString programIconName;
-#endif
     QVariant programLogo;
     QString customAuthorPlainText, customAuthorRichText;
     bool customAuthorTextEnabled;
 
     QString organizationDomain;
-    QString _ocsProviderUrl;
     QString desktopFileName;
 
     // Everything dr.konqi needs, we store as utf-8, so we
@@ -615,36 +609,15 @@ KAboutData &KAboutData::operator=(const KAboutData &other)
     return *this;
 }
 
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 65)
-KAboutData KAboutData::fromPluginMetaData(const KPluginMetaData &plugin)
+KAboutData &KAboutData::addAuthor(const QString &name, const QString &task, const QString &emailAddress, const QString &webAddress, const QUrl &avatarUrl)
 {
-    KAboutData ret(plugin.pluginId(),
-                   plugin.name(),
-                   plugin.version(),
-                   plugin.description(),
-                   KAboutLicense::byKeyword(plugin.license()).key(),
-                   plugin.copyrightText(),
-                   plugin.extraInformation(),
-                   plugin.website());
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 2)
-    ret.d->programIconName = plugin.iconName();
-#endif
-    ret.d->_authorList = plugin.authors();
-    ret.d->_translatorList = plugin.translators();
-    ret.d->_creditList = plugin.otherContributors();
-    return ret;
-}
-#endif
-
-KAboutData &KAboutData::addAuthor(const QString &name, const QString &task, const QString &emailAddress, const QString &webAddress, const QString &ocsUsername)
-{
-    d->_authorList.append(KAboutPerson(name, task, emailAddress, webAddress, ocsUsername));
+    d->_authorList.append(KAboutPerson(name, task, emailAddress, webAddress, avatarUrl));
     return *this;
 }
 
-KAboutData &KAboutData::addCredit(const QString &name, const QString &task, const QString &emailAddress, const QString &webAddress, const QString &ocsUsername)
+KAboutData &KAboutData::addCredit(const QString &name, const QString &task, const QString &emailAddress, const QString &webAddress, const QUrl &avatarUrl)
 {
-    d->_creditList.append(KAboutPerson(name, task, emailAddress, webAddress, ocsUsername));
+    d->_creditList.append(KAboutPerson(name, task, emailAddress, webAddress, avatarUrl));
     return *this;
 }
 
@@ -727,12 +700,6 @@ KAboutData &KAboutData::setDisplayName(const QString &_displayName)
     return *this;
 }
 
-KAboutData &KAboutData::setOcsProvider(const QString &_ocsProviderUrl)
-{
-    d->_ocsProviderUrl = _ocsProviderUrl;
-    return *this;
-}
-
 KAboutData &KAboutData::setVersion(const QByteArray &_version)
 {
     d->_version = _version;
@@ -829,10 +796,7 @@ const char *KAboutData::internalProductName() const
 
 QString KAboutData::displayName() const
 {
-    if (!d->_displayName.isEmpty()) {
-        return d->_displayName;
-    }
-    return componentName();
+    return d->_displayName;
 }
 
 /// @internal
@@ -843,19 +807,6 @@ const char *KAboutData::internalProgramName() const
     return d->_internalProgramName.constData();
 }
 
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 2)
-QString KAboutData::programIconName() const
-{
-    return d->programIconName.isEmpty() ? componentName() : d->programIconName;
-}
-
-KAboutData &KAboutData::setProgramIconName(const QString &iconName)
-{
-    d->programIconName = iconName;
-    return *this;
-}
-#endif
-
 QVariant KAboutData::programLogo() const
 {
     return d->programLogo;
@@ -867,11 +818,6 @@ KAboutData &KAboutData::setProgramLogo(const QVariant &image)
     return *this;
 }
 
-QString KAboutData::ocsProviderUrl() const
-{
-    return d->_ocsProviderUrl;
-}
-
 QString KAboutData::version() const
 {
     return QString::fromUtf8(d->_version.data());
@@ -932,11 +878,12 @@ QList<KAboutPerson> KAboutDataPrivate::parseTranslators(const QString &translato
         return {};
     }
 
-    const QStringList nameList(translatorName.split(QLatin1Char(',')));
+    // use list of string views to delay creating new QString instances after the white-space trimming
+    const QList<QStringView> nameList = QStringView(translatorName).split(QLatin1Char(','));
 
-    QStringList emailList;
+    QList<QStringView> emailList;
     if (!translatorEmail.isEmpty() && translatorEmail != QLatin1String("Your emails")) {
-        emailList = translatorEmail.split(QLatin1Char(','), Qt::KeepEmptyParts);
+        emailList = QStringView(translatorEmail).split(QLatin1Char(','), Qt::KeepEmptyParts);
     }
 
     QList<KAboutPerson> personList;
@@ -944,14 +891,14 @@ QList<KAboutPerson> KAboutDataPrivate::parseTranslators(const QString &translato
 
     auto eit = emailList.constBegin();
 
-    for (const QString &name : nameList) {
-        QString email;
+    for (const QStringView &name : nameList) {
+        QStringView email;
         if (eit != emailList.constEnd()) {
             email = *eit;
             ++eit;
         }
 
-        personList.append(KAboutPerson(name.trimmed(), email.trimmed(), true));
+        personList.append(KAboutPerson(name.trimmed().toString(), email.trimmed().toString(), true));
     }
 
     return personList;
@@ -1066,17 +1013,11 @@ public:
     ~KAboutDataRegistry()
     {
         delete m_appData;
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 76)
-        qDeleteAll(m_pluginData);
-#endif
     }
     KAboutDataRegistry(const KAboutDataRegistry &) = delete;
     KAboutDataRegistry &operator=(const KAboutDataRegistry &) = delete;
 
     KAboutData *m_appData;
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 76)
-    QHash<QString, KAboutData *> m_pluginData;
-#endif
 };
 
 Q_GLOBAL_STATIC(KAboutDataRegistry, s_registry)
@@ -1102,6 +1043,8 @@ KAboutData KAboutData::applicationData()
     if (!aboutData) {
         // init from current Q*Application data
         aboutData = new KAboutData(QCoreApplication::applicationName(), QString(), QString());
+        // Unset the default (KDE) bug address, this is likely a third-party app. https://bugs.kde.org/show_bug.cgi?id=473517
+        aboutData->setBugAddress(QByteArray());
         // For applicationDisplayName & desktopFileName, which are only properties of QGuiApplication,
         // we have to try to get them via the property system, as the static getter methods are
         // part of QtGui only. Disadvantage: requires an app instance.
@@ -1179,27 +1122,6 @@ void KAboutData::setApplicationData(const KAboutData &aboutData)
     // that increases behavioural complexity a little.
 }
 
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 76)
-void KAboutData::registerPluginData(const KAboutData &aboutData)
-{
-    auto &data = s_registry->m_pluginData[aboutData.componentName()];
-    if (data) {
-        // silently ignore double registration, assuming it's for the same plugin
-        // all of this is getting deprecated anyways, we just don't want to leak anything
-        return;
-    }
-    data = new KAboutData(aboutData);
-}
-#endif
-
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 76)
-KAboutData *KAboutData::pluginData(const QString &componentName)
-{
-    KAboutData *ad = s_registry->m_pluginData.value(componentName);
-    return ad;
-}
-#endif
-
 // only for KCrash (no memory allocation allowed)
 const KAboutData *KAboutData::applicationDataPointer()
 {
@@ -1273,38 +1195,4 @@ void KAboutData::processCommandLine(QCommandLineParser *parser)
     }
 }
 
-template<class T>
-QVariantList listToVariant(const QList<T> &values)
-{
-    QVariantList ret;
-    ret.reserve(values.count());
-    for (const auto &value : values) {
-        ret << QVariant::fromValue(value);
-    }
-    return ret;
-}
-
-QVariantList KAboutData::licensesVariant() const
-{
-    return listToVariant(d->_licenseList);
-}
-
-QVariantList KAboutData::authorsVariant() const
-{
-    return listToVariant(d->_authorList);
-}
-
-QVariantList KAboutData::creditsVariant() const
-{
-    return listToVariant(d->_creditList);
-}
-
-QVariantList KAboutData::translatorsVariant() const
-{
-    return listToVariant(d->_translatorList);
-}
-
-QVariantList KAboutData::componentsVariant() const
-{
-    return listToVariant(d->_componentList);
-}
+#include "moc_kaboutdata.cpp"
