@@ -16,6 +16,7 @@
 
 #include <QSharedDataPointer>
 #include <QString>
+#include <QUrl>
 #include <QVariant>
 #include <kcoreaddons_export.h>
 #include <memory>
@@ -24,7 +25,6 @@
 class QCommandLineParser;
 class QJsonObject;
 class KAboutData;
-class KPluginMetaData;
 namespace KCrash
 {
 #ifdef KCOREADDONS_STATIC
@@ -65,7 +65,7 @@ class KCOREADDONS_EXPORT KAboutPerson
     Q_PROPERTY(QString task READ task CONSTANT)
     Q_PROPERTY(QString emailAddress READ emailAddress CONSTANT)
     Q_PROPERTY(QString webAddress READ webAddress CONSTANT)
-    Q_PROPERTY(QString ocsUsername READ ocsUsername CONSTANT)
+    Q_PROPERTY(QUrl avatarUrl READ avatarUrl CONSTANT)
     friend class KAboutData;
     friend class KAboutDataPrivate;
 
@@ -81,7 +81,7 @@ public:
      *
      * @param webAddress Home page of the person.
      *
-     * @param ocsUsername Open Collaboration Services username of the person.
+     * @param avatarUrl URL to the avatar of the person, since 6.0
      *
      * @p name default argument @since 5.53
      */
@@ -89,7 +89,7 @@ public:
                           const QString &task = QString(),
                           const QString &emailAddress = QString(),
                           const QString &webAddress = QString(),
-                          const QString &ocsUsername = QString());
+                          const QUrl &avatarUrl = QUrl());
 
     /**
      * Copy constructor.  Performs a deep copy.
@@ -134,11 +134,10 @@ public:
     QString webAddress() const;
 
     /**
-     * The person's Open Collaboration Services username
-     * @return the persons OCS username (can be QString(), if it has been
-     *           constructed with an empty username)
+     * @return an URL pointing to the user's avatar
+     * @since 6.0
      */
-    QString ocsUsername() const;
+    QUrl avatarUrl() const;
 
     /**
      * Creates a @c KAboutPerson from a JSON object with the following structure:
@@ -149,9 +148,10 @@ public:
      * Email      | emailAddress()
      * Task       | task()
      * Website    | webAddress()
-     * UserName   | ocsUsername()
+     * AvatarUrl   | avatarUrl()
      *
      * The @c Name and @c Task key are translatable (by using e.g. a "Task[de_DE]" key)
+     * The AvatarUrl exists since version 6.0
      *
      * @since 5.18
      */
@@ -161,12 +161,14 @@ private:
     /**
      * @internal Used by KAboutData to construct translator data.
      */
-    explicit KAboutPerson(const QString &name, const QString &email, bool disambiguation);
+    KCOREADDONS_NO_EXPORT explicit KAboutPerson(const QString &name, const QString &email, bool disambiguation);
 
 private:
     QSharedDataPointer<class KAboutPersonPrivate> d;
 };
 
+Q_DECLARE_TYPEINFO(KAboutPerson, Q_RELOCATABLE_TYPE);
+
 /**
  * This class is used to store information about a license.
  * The license can be one of some predefined, one given as text or one
@@ -201,11 +203,10 @@ public:
         LGPL_V2 = LGPL, ///< LGPL_V2, this has the same value as LicenseKey::LGPL, see https://spdx.org/licenses/LGPL-2.0-only.html
         BSDL = 3, ///< BSDL, see https://spdx.org/licenses/BSD-2-Clause.html
         Artistic = 4, ///< Artistic, see https://spdx.org/licenses/Artistic-2.0.html
-        QPL = 5, ///< QPL
-        QPL_V1_0 = QPL, ///< QPL_V1_0, this has the same value as LicenseKey::QPL, see https://spdx.org/licenses/QPL-1.0.html
-        GPL_V3 = 6, ///< GPL_V3, see https://spdx.org/licenses/GPL-3.0.html
-        LGPL_V3 = 7, ///< LGPL_V3, see https://spdx.org/licenses/LGPL-3.0-only.html
-        LGPL_V2_1 = 8, ///< LGPL_V2_1 @since 5.25, see https://spdx.org/licenses/LGPL-2.1-only.html
+        GPL_V3 = 5, ///< GPL_V3, see https://spdx.org/licenses/GPL-3.0.html
+        LGPL_V3 = 6, ///< LGPL_V3, see https://spdx.org/licenses/LGPL-3.0-only.html
+        LGPL_V2_1 = 7, ///< LGPL_V2_1 @since 5.25, see https://spdx.org/licenses/LGPL-2.1-only.html
+        MIT = 8, ///< MIT @since 6.0, see https://spdx.org/licenses/MIT.html
     };
     Q_ENUM(LicenseKey)
 
@@ -315,28 +316,32 @@ private:
     /**
      * @internal Used by KAboutData to construct a predefined license.
      */
-    explicit KAboutLicense(enum KAboutLicense::LicenseKey licenseType, enum KAboutLicense::VersionRestriction versionRestriction, const KAboutData *aboutData);
+    KCOREADDONS_NO_EXPORT explicit KAboutLicense(enum KAboutLicense::LicenseKey licenseType,
+                                                 enum KAboutLicense::VersionRestriction versionRestriction,
+                                                 const KAboutData *aboutData);
     /**
      * @internal Used by KAboutData to construct a predefined license.
      */
-    explicit KAboutLicense(enum KAboutLicense::LicenseKey licenseType, const KAboutData *aboutData);
+    KCOREADDONS_NO_EXPORT explicit KAboutLicense(enum KAboutLicense::LicenseKey licenseType, const KAboutData *aboutData);
     /**
      * @internal Used by KAboutData to construct a KAboutLicense
      */
-    explicit KAboutLicense(const KAboutData *aboutData);
+    KCOREADDONS_NO_EXPORT explicit KAboutLicense(const KAboutData *aboutData);
     /**
      * @internal Used by KAboutData to construct license by given text
      */
-    void setLicenseFromPath(const QString &pathToFile);
+    KCOREADDONS_NO_EXPORT void setLicenseFromPath(const QString &pathToFile);
     /**
      * @internal Used by KAboutData to construct license by given text
      */
-    void setLicenseFromText(const QString &licenseText);
+    KCOREADDONS_NO_EXPORT void setLicenseFromText(const QString &licenseText);
 
 private:
     QSharedDataPointer<class KAboutLicensePrivate> d;
 };
 
+Q_DECLARE_TYPEINFO(KAboutLicense, Q_RELOCATABLE_TYPE);
+
 /**
  * This class is used to store information about a third party component.
  * It can store the component's name, a description, a link to a website
@@ -394,10 +399,10 @@ public:
      * @p name default argument
      */
     explicit KAboutComponent(const QString &name = QString(),
-                          const QString &description = QString(),
-                          const QString &version = QString(),
-                          const QString &webAddress = QString(),
-                          enum KAboutLicense::LicenseKey licenseType = KAboutLicense::Unknown);
+                             const QString &description = QString(),
+                             const QString &version = QString(),
+                             const QString &webAddress = QString(),
+                             enum KAboutLicense::LicenseKey licenseType = KAboutLicense::Unknown);
 
     /**
      * Convenience constructor
@@ -416,10 +421,10 @@ public:
      * @p name default argument
      */
     explicit KAboutComponent(const QString &name,
-                          const QString &description,
-                          const QString &version,
-                          const QString &webAddress,
-                          const QString &pathToLicenseFile);
+                             const QString &description,
+                             const QString &version,
+                             const QString &webAddress,
+                             const QString &pathToLicenseFile);
 
     /**
      * Copy constructor. Performs a deep copy.
@@ -470,6 +475,8 @@ private:
     QSharedDataPointer<class KAboutComponentPrivate> d;
 };
 
+Q_DECLARE_TYPEINFO(KAboutComponent, Q_RELOCATABLE_TYPE);
+
 /**
  * @class KAboutData kaboutdata.h KAboutData
  *
@@ -543,11 +550,11 @@ class KCOREADDONS_EXPORT KAboutData
     Q_PROPERTY(QString bugAddress READ bugAddress CONSTANT)
     Q_PROPERTY(QString version READ version CONSTANT)
     Q_PROPERTY(QString otherText READ otherText CONSTANT)
-    Q_PROPERTY(QVariantList authors READ authorsVariant CONSTANT) // constant in practice as addAuthor is not exposed to Q_GADGET
-    Q_PROPERTY(QVariantList credits READ creditsVariant CONSTANT)
-    Q_PROPERTY(QVariantList translators READ translatorsVariant CONSTANT)
-    Q_PROPERTY(QVariantList components READ componentsVariant CONSTANT)
-    Q_PROPERTY(QVariantList licenses READ licensesVariant CONSTANT)
+    Q_PROPERTY(QList<KAboutPerson> authors READ authors CONSTANT) // constant in practice as addAuthor is not exposed to Q_GADGET
+    Q_PROPERTY(QList<KAboutPerson> credits READ credits CONSTANT)
+    Q_PROPERTY(QList<KAboutPerson> translators READ translators CONSTANT)
+    Q_PROPERTY(QList<KAboutComponent> components READ components CONSTANT)
+    Q_PROPERTY(QList<KAboutLicense> licenses READ licenses CONSTANT)
     Q_PROPERTY(QString copyrightStatement READ copyrightStatement CONSTANT)
     Q_PROPERTY(QString desktopFileName READ desktopFileName CONSTANT)
 public:
@@ -583,43 +590,6 @@ public:
      */
     static void setApplicationData(const KAboutData &aboutData);
 
-// BUILD, not ENABLE, as producers need to support the registry for backward-compat
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 76)
-    /**
-     * Register the KAboutData information for a plugin.
-     * Call this from the constructor of the plugin.
-     * This will register the plugin's @p aboutData under the component name
-     * that was set in @p aboutData.
-     * @deprecated Since 5.76. The central registry is to be removed in the future
-     * in favour of plugin type specific local registries, using KPluginMetaData.
-     */
-    KCOREADDONS_DEPRECATED_VERSION(5, 76, "See API docs")
-    static void registerPluginData(const KAboutData &aboutData);
-#endif
-
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 76)
-    /**
-     * Return the KAboutData for the given plugin identified by @p componentName.
-     * @deprecated Since 5.76. The central registry is to be removed in the future
-     * in favour of plugin type specific local registries, using KPluginMetaData.
-     */
-    KCOREADDONS_DEPRECATED_VERSION(5, 76, "See API docs")
-    static KAboutData *pluginData(const QString &componentName);
-#endif
-
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 65)
-    /**
-     * Creates a @c KAboutData from the given @p plugin metadata
-     *
-     * @since 5.18
-     * @deprecated Since 5.65, use KAboutPluginDialog to show info about a plugin
-     * instead of KAboutApplicationDialog, with the latter having had been the
-     * only known need for this conversion.
-     */
-    KCOREADDONS_DEPRECATED_VERSION(5, 65, "See API docs")
-    static KAboutData fromPluginMetaData(const KPluginMetaData &plugin);
-#endif
-
 public:
     /**
      * Constructor.
@@ -735,15 +705,22 @@ public:
      *        Start the address with "http://". "http://some.domain" is
      *        correct, "some.domain" is not. Can be left empty.
      *
-     * @param ocsUsername The person's Open Collaboration Services username.
-     *        The provider can be optionally specified with @see setOcsProvider.
-     *
+     * @param avatarUrl URL to the avatar of the person
      */
     KAboutData &addAuthor(const QString &name,
                           const QString &task = QString(),
                           const QString &emailAddress = QString(),
                           const QString &webAddress = QString(),
-                          const QString &ocsUsername = QString());
+                          const QUrl &avatarUrl = QUrl());
+
+    /**
+     * @overload
+     * @since 6.0
+     */
+    KAboutData &addAuthor(const QString &name, const QString &task, const QString &emailAddress, const QString &webAddress, const QString &kdeStoreUsername)
+    {
+        return addAuthor(name, task, emailAddress, webAddress, QUrl(QStringLiteral("https://store.kde.org/avatar/") + kdeStoreUsername));
+    }
 
     /**
      * Defines a person that deserves credit.
@@ -764,15 +741,22 @@ public:
      *        Start the address with "http://". "http://some.domain" is
      *        is correct, "some.domain" is not. Can be left empty.
      *
-     * @param ocsUsername The person's Open Collaboration Services username.
-     *        The provider can be optionally specified with @see setOcsProvider.
-     *
+     * @param avatarUrl URL to the avatar of the person
      */
     KAboutData &addCredit(const QString &name,
                           const QString &task = QString(),
                           const QString &emailAddress = QString(),
                           const QString &webAddress = QString(),
-                          const QString &ocsUsername = QString());
+                          const QUrl &avatarUrl = QUrl());
+
+    /**
+     * @overload
+     * @since 6.0
+     */
+    KAboutData &addCredit(const QString &name, const QString &task, const QString &emailAddress, const QString &webAddress, const QString &kdeStoreUsername)
+    {
+        return addCredit(name, task, emailAddress, webAddress, QUrl(QStringLiteral("https://store.kde.org/avatar/") + kdeStoreUsername));
+    }
 
     /**
      * @brief Sets the name(s) of the translator(s) of the GUI.
@@ -820,10 +804,10 @@ public:
      * @since 5.84
      */
     KAboutData &addComponent(const QString &name,
-                           const QString &description = QString(),
-                           const QString &version = QString(),
-                           const QString &webAddress = QString(),
-                           KAboutLicense::LicenseKey licenseKey = KAboutLicense::Unknown);
+                             const QString &description = QString(),
+                             const QString &version = QString(),
+                             const QString &webAddress = QString(),
+                             KAboutLicense::LicenseKey licenseKey = KAboutLicense::Unknown);
 
     /**
      * Defines a component that is used by the application with a custom license text file.
@@ -848,11 +832,8 @@ public:
      *
      * @since 5.84
      */
-    KAboutData &addComponent(const QString &name,
-                           const QString &description,
-                           const QString &version,
-                           const QString &webAddress,
-                           const QString &pathToLicenseFile);
+    KAboutData &
+    addComponent(const QString &name, const QString &description, const QString &version, const QString &webAddress, const QString &pathToLicenseFile);
 
     /**
      * Defines a license text, which is translated.
@@ -918,22 +899,6 @@ public:
      */
     KAboutData &setDisplayName(const QString &displayName);
 
-#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 2)
-    /**
-     * Obsolete method
-     *
-     * This method used to set the icon name but this is no longer
-     * possible in KDE Frameworks 5 because KCoreAddons does not
-     * depend on QtGui.
-     *
-     * @param iconName name of the icon. Example: "accessories-text-editor"
-     * @see programIconName()
-     *
-     * @deprecated since 5.2, use QApplication::setWindowIcon(QIcon::fromTheme()) instead.
-     */
-    KCOREADDONS_DEPRECATED_VERSION(5, 2, "Use QApplication::setWindowIcon")
-    KAboutData &setProgramIconName(const QString &iconName);
-#endif
     /**
      * Defines the program logo.
      *
@@ -951,20 +916,6 @@ public:
      */
     KAboutData &setProgramLogo(const QVariant &image);
 
-    /**
-     * Specifies an Open Collaboration Services provider by URL.
-     * A provider file must be available for the chosen provider.
-     *
-     * Use this if you need to override the default provider.
-     *
-     * If this method is not used, all the KAboutPerson OCS usernames
-     * will be used with the openDesktop.org entry from the default
-     * provider file.
-     *
-     * @param providerUrl The provider URL as defined in the provider file.
-     */
-    KAboutData &setOcsProvider(const QString &providerUrl);
-
     /**
      * Defines the program version string.
      *
@@ -1083,10 +1034,6 @@ public:
      * component name "foo" the name of an installed D-Bus service file needs to be
      * "org.bar.foo.service" or the name of the installed desktop file "org.bar.foo.desktop"
      * (and the desktopFileName property accordingly set to "org.bar.foo").
-     * For still supporting the deprecated start of services via KToolInvocation,
-     * the desktop file needs to have an entry with the key "X-DBUS-ServiceName"
-     * and a value which matches the used D-Bus "well-known name" as just described,
-     * so with the above used values it needs a line "X-DBUS-ServiceName=org.bar.foo"
      *
      * @param domain the domain name, for instance kde.org, koffice.org, etc.
      *
@@ -1144,21 +1091,6 @@ public:
      */
     const char *internalProgramName() const;
 
-// Not using KCOREADDONS_ENABLE_DEPRECATED_SINCE because KXmlGui and KConfigWidgets need this, for compat
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 2)
-    /**
-     * Returns the program's icon name.
-     *
-     * The default value is componentName().
-     * @return the program's icon name.
-     *
-     * This is mostly for compatibility, given that setProgramIconName is deprecated.
-     * @deprecated Since 5.2, Use QGuiApplication::windowIcon instead
-     */
-    KCOREADDONS_DEPRECATED_VERSION(5, 2, "Use QGuiApplication::windowIcon instead")
-    QString programIconName() const;
-#endif
-
     /**
      * Returns the program logo image.
      *
@@ -1170,12 +1102,6 @@ public:
      */
     QVariant programLogo() const;
 
-    /**
-     * Returns the chosen Open Collaboration Services provider URL.
-     * @return the provider URL.
-     */
-    QString ocsProviderUrl() const;
-
     /**
      * Returns the program's version.
      * @return the version string.
@@ -1373,22 +1299,12 @@ public:
     QString desktopFileName() const;
 
 private:
-    QVariantList licensesVariant() const;
-    QVariantList authorsVariant() const;
-    QVariantList creditsVariant() const;
-    QVariantList translatorsVariant() const;
-    QVariantList componentsVariant() const;
-
     friend void KCrash::defaultCrashHandler(int sig);
+    // exported for KCrash, no other users intended
     static const KAboutData *applicationDataPointer();
 
 private:
     std::unique_ptr<class KAboutDataPrivate> const d;
 };
 
-Q_DECLARE_METATYPE(KAboutData)
-Q_DECLARE_METATYPE(KAboutLicense)
-Q_DECLARE_METATYPE(KAboutPerson)
-Q_DECLARE_METATYPE(KAboutComponent)
-
 #endif
