@@ -6,44 +6,16 @@
 */
 
 #include "ktexttohtml.h"
+#include "kemoticonsparser_p.h"
 #include "ktexttohtml_p.h"
-#include "ktexttohtmlemoticonsinterface.h"
 
 #include <QCoreApplication>
 #include <QFile>
-#include <QPluginLoader>
 #include <QRegularExpression>
 #include <QStringList>
 
 #include <limits.h>
 
-#include "kcoreaddons_debug.h"
-
-static KTextToHTMLEmoticonsInterface *s_emoticonsInterface = nullptr;
-
-static void loadEmoticonsPlugin()
-{
-    static bool triedLoadPlugin = false;
-    if (!triedLoadPlugin) {
-        triedLoadPlugin = true;
-
-        // Check if QGuiApplication::platformName property exists. This is a
-        // hackish way of determining whether we are running QGuiApplication,
-        // because we cannot load the FrameworkIntegration plugin into a
-        // QCoreApplication, as it would crash immediately
-        if (qApp->metaObject()->indexOfProperty("platformName") > -1) {
-            QPluginLoader lib(QStringLiteral("kf5/KEmoticonsIntegrationPlugin"));
-            QObject *rootObj = lib.instance();
-            if (rootObj) {
-                s_emoticonsInterface = rootObj->property(KTEXTTOHTMLEMOTICONS_PROPERTY).value<KTextToHTMLEmoticonsInterface *>();
-            }
-        }
-    }
-    if (!s_emoticonsInterface) {
-        s_emoticonsInterface = new KTextToHTMLEmoticonsDummy();
-    }
-}
-
 KTextToHTMLHelper::KTextToHTMLHelper(const QString &plainText, int pos, int maxUrlLen, int maxAddressLen)
     : mText(plainText)
     , mMaxUrlLen(maxUrlLen)
@@ -52,14 +24,6 @@ KTextToHTMLHelper::KTextToHTMLHelper(const QString &plainText, int pos, int maxU
 {
 }
 
-KTextToHTMLEmoticonsInterface *KTextToHTMLHelper::emoticonsInterface() const
-{
-    if (!s_emoticonsInterface) {
-        loadEmoticonsPlugin();
-    }
-    return s_emoticonsInterface;
-}
-
 QString KTextToHTMLHelper::getEmailAddress()
 {
     QString address;
@@ -139,46 +103,52 @@ QString KTextToHTMLHelper::getPhoneNumber()
 
     // this isn't 100% accurate, we filter stuff below that is too hard to capture with a regexp
     static const QRegularExpression telPattern(QStringLiteral(R"([+0](( |( ?[/-] ?)?)\(?\d+\)?+){6,30})"));
-    const auto match = telPattern.match(mText, mPos, QRegularExpression::NormalMatch, QRegularExpression::AnchoredMatchOption);
+    const auto match = telPattern.match(mText, mPos, QRegularExpression::NormalMatch, QRegularExpression::AnchorAtOffsetMatchOption);
     if (match.hasMatch()) {
-        auto m = match.captured();
+        QStringView matchedText = match.capturedView();
         // check for maximum number of digits (15), see https://en.wikipedia.org/wiki/Telephone_numbering_plan
-        const int count = std::count_if(m.begin(), m.end(), [](const QChar &c) {
+        const int digitsCount = std::count_if(matchedText.cbegin(), matchedText.cend(), [](const QChar c) {
             return c.isDigit();
         });
-        if (count > 15) {
+
+        if (digitsCount > 15) {
             return {};
         }
+
         // only one / is allowed, otherwise we trigger on dates
-        if (std::count(m.begin(), m.end(), QLatin1Char('/')) > 1) {
+        if (matchedText.count(QLatin1Char('/')) > 1) {
             return {};
         }
 
         // parenthesis need to be balanced, and must not be nested
         int openIdx = -1;
-        for (int i = 0; i < m.size(); ++i) {
-            if ((m[i] == QLatin1Char('(') && openIdx >= 0) || (m[i] == QLatin1Char(')') && openIdx < 0)) {
+        for (int i = 0, size = matchedText.size(); i < size; ++i) {
+            const QChar ch = matchedText.at(i);
+            if ((ch == QLatin1Char('(') && openIdx >= 0) || (ch == QLatin1Char(')') && openIdx < 0)) {
                 return {};
             }
-            if (m[i] == QLatin1Char('(')) {
+
+            if (ch == QLatin1Char('(')) {
                 openIdx = i;
-            } else if (m[i] == QLatin1Char(')')) {
+            } else if (ch == QLatin1Char(')')) {
                 openIdx = -1;
             }
         }
+
         if (openIdx > 0) {
-            m = m.leftRef(openIdx - 1).trimmed().toString();
+            matchedText.truncate(openIdx - 1);
+            matchedText = matchedText.trimmed();
         }
 
         // check if there's a plausible separator at the end
-        const QString allowedEndSeparators = QStringLiteral(" \r\t\n,.");
-        const auto l = m.size();
-        if (mText.size() > mPos + l && !allowedEndSeparators.contains(mText.at(mPos + l))) {
+        const int matchedTextLength = matchedText.size();
+        const int endIdx = mPos + matchedTextLength;
+        if (endIdx < mText.size() && !QStringView(u" \r\t\n,.").contains(mText.at(endIdx))) {
             return {};
         }
 
-        mPos += l - 1;
-        return m;
+        mPos += matchedTextLength - 1;
+        return matchedText.toString();
     }
     return {};
 }
@@ -210,7 +180,7 @@ bool KTextToHTMLHelper::atUrl() const
         }
     }
 
-    const auto segment = mText.midRef(mPos);
+    const auto segment = QStringView(mText).mid(mPos);
     /* clang-format off */
     return segment.startsWith(QLatin1String("http://"))
         || segment.startsWith(QLatin1String("https://"))
@@ -405,7 +375,7 @@ QString KTextToHTMLHelper::highlightedText()
 
     QRegularExpression re(QStringLiteral("\\%1([^\\s|^\\%1].*[^\\s|^\\%1])\\%1").arg(ch));
     re.setPatternOptions(QRegularExpression::InvertedGreedinessOption);
-    const auto match = re.match(mText, mPos, QRegularExpression::NormalMatch, QRegularExpression::AnchoredMatchOption);
+    const auto match = re.match(mText, mPos, QRegularExpression::NormalMatch, QRegularExpression::AnchorAtOffsetMatchOption);
 
     if (match.hasMatch()) {
         if (match.capturedStart() == mPos) {
@@ -417,13 +387,13 @@ QString KTextToHTMLHelper::highlightedText()
             mPos += length - 1;
             switch (ch.toLatin1()) {
             case '*':
-                return QLatin1String("<b>*") + match.capturedRef(1) + QLatin1String("*</b>");
+                return QLatin1String("<b>*") + match.capturedView(1) + QLatin1String("*</b>");
             case '_':
-                return QLatin1String("<u>_") + match.capturedRef(1) + QLatin1String("_</u>");
+                return QLatin1String("<u>_") + match.capturedView(1) + QLatin1String("_</u>");
             case '/':
-                return QLatin1String("<i>/") + match.capturedRef(1) + QLatin1String("/</i>");
+                return QLatin1String("<i>/") + match.capturedView(1) + QLatin1String("/</i>");
             case '-':
-                return QLatin1String("<s>-") + match.capturedRef(1) + QLatin1String("-</s>");
+                return QLatin1String("<s>-") + match.capturedView(1) + QLatin1String("-</s>");
             }
         }
     }
@@ -507,9 +477,7 @@ QString KTextToHTML::convertToHtml(const QString &plainText, const KTextToHTML::
                 str = helper.getUrl(&badUrl);
                 if (badUrl) {
                     QString resultBadUrl;
-                    const int helperTextSize(helper.mText.count());
-                    for (int i = 0; i < helperTextSize; ++i) {
-                        const QChar chBadUrl = helper.mText.at(i);
+                    for (const QChar chBadUrl : std::as_const(helper.mText)) {
                         if (chBadUrl == QLatin1Char('&')) {
                             resultBadUrl += QLatin1String("&amp;");
                         } else if (chBadUrl == QLatin1Char('"')) {
@@ -574,16 +542,7 @@ QString KTextToHTML::convertToHtml(const QString &plainText, const KTextToHTML::
     }
 
     if (flags & ReplaceSmileys) {
-        const QStringList exclude = {QStringLiteral("(c)"), QStringLiteral("(C)"), QStringLiteral("&gt;:-("), QStringLiteral("&gt;:("), QStringLiteral("(B)"),
-                                     QStringLiteral("(b)"), QStringLiteral("(P)"), QStringLiteral("(p)"),     QStringLiteral("(O)"),    QStringLiteral("(o)"),
-                                     QStringLiteral("(D)"), QStringLiteral("(d)"), QStringLiteral("(E)"),     QStringLiteral("(e)"),    QStringLiteral("(K)"),
-                                     QStringLiteral("(k)"), QStringLiteral("(I)"), QStringLiteral("(i)"),     QStringLiteral("(L)"),    QStringLiteral("(l)"),
-                                     QStringLiteral("(8)"), QStringLiteral("(T)"), QStringLiteral("(t)"),     QStringLiteral("(G)"),    QStringLiteral("(g)"),
-                                     QStringLiteral("(F)"), QStringLiteral("(f)"), QStringLiteral("(H)"),     QStringLiteral("8)"),     QStringLiteral("(N)"),
-                                     QStringLiteral("(n)"), QStringLiteral("(Y)"), QStringLiteral("(y)"),     QStringLiteral("(U)"),    QStringLiteral("(u)"),
-                                     QStringLiteral("(W)"), QStringLiteral("(w)"), QStringLiteral("(6)")};
-
-        result = helper.emoticonsInterface()->parseEmoticons(result, true, exclude);
+        result = KEmoticonsParser::parseEmoticons(result);
     }
 
     return result;
